
ROUTINE-LEVEL ON ERROR UNDO, THROW. 

USING Progress.Lang.*.
USING OEUnit.Assertion.Assert.
USING OEUnit.Util.*.
USING OEUnit.Tests.Util.*.

CLASS OEUnit.Tests.Util.ListTest :
    
  DEFINE PRIVATE VARIABLE list1 AS List NO-UNDO.
  DEFINE PRIVATE VARIABLE obj1 AS Object NO-UNDO.
  DEFINE PRIVATE VARIABLE obj2 AS Object NO-UNDO. 
  DEFINE PRIVATE VARIABLE obj3 AS Object NO-UNDO.
  DEFINE PRIVATE VARIABLE obj4 AS Object NO-UNDO.
  DEFINE PRIVATE VARIABLE refobj AS Object NO-UNDO.

  @Before.
  METHOD PUBLIC VOID CreateListAndAddElements():
    list1 = NEW List(TRUE).
    obj1 = NEW Object().
    obj2 = NEW Object().
    obj3 = NEW Object().
    obj4 = NEW Object().
    list1:AddElement(obj1).
    list1:AddElement(obj2).
    list1:AddElement(obj3).
    list1:AddElement(obj4).
  END METHOD.    

  @After.
  METHOD PUBLIC VOID DeleteListAndElements():
    DELETE OBJECT list1 NO-ERROR.
    DELETE OBJECT obj1 NO-ERROR.
    DELETE OBJECT obj2 NO-ERROR.
    DELETE OBJECT obj3 NO-ERROR.
    DELETE OBJECT obj4 NO-ERROR.
  END METHOD.    

  @Test.
  METHOD PUBLIC VOID TestMoveAndReset():
    list1:MoveNext().
    Assert:AreSame(obj1,list1:CurrentElement).
    list1:MoveNext().
    Assert:AreSame(obj2,list1:CurrentElement).  
    list1:ResetPointer().                       
    list1:MoveNext().
    Assert:AreSame(obj1,list1:CurrentElement).  
    list1:MoveNext().
    Assert:AreSame(obj2,list1:CurrentElement).  
    list1:ResetPointer().                       
    list1:MovePrevious().
    Assert:AreSame(obj4,list1:CurrentElement).
    list1:MovePrevious().
    Assert:AreSame(obj3,list1:CurrentElement).
    list1:MoveFirst().
    Assert:AreSame(obj1,list1:CurrentElement).
    list1:MoveLast().
    Assert:AreSame(obj4,list1:CurrentElement).    
  END METHOD.
  
  @Test.
  METHOD PUBLIC VOID MoveElementForwards():
    list1:MoveElement(1,3).
    Assert:AreSame(obj1,list1:GetElement(3)).
    Assert:AreSame(obj2,list1:GetElement(1)).
    Assert:AreSame(obj3,list1:GetElement(2)).
    Assert:AreSame(obj4,list1:GetElement(4)).
  END METHOD.

  @Test.
  METHOD PUBLIC VOID MoveElementBackwards():
    list1:MoveElement(4,1).
    Assert:AreSame(obj1,list1:GetElement(2)).
    Assert:AreSame(obj2,list1:GetElement(3)).
    Assert:AreSame(obj3,list1:GetElement(4)).
    Assert:AreSame(obj4,list1:GetElement(1)).
  END METHOD.

  @Test.
  METHOD PUBLIC VOID InsertElement():
    list1:InsertElement(obj1, 3).
    Assert:AreSame(obj1,list1:GetElement(1)).
    Assert:AreSame(obj2,list1:GetElement(2)).
    Assert:AreSame(obj1,list1:GetElement(3)).
    Assert:AreSame(obj3,list1:GetElement(4)).
    Assert:AreSame(obj4,list1:GetElement(5)).
  END METHOD.
   
  @Test.
  METHOD PUBLIC VOID InsertElementBeforeStart():    
    list1:InsertElement(obj4, -1).
    Assert:AreSame(obj4,list1:GetElement(1)).
    Assert:AreSame(obj1,list1:GetElement(2)).
    Assert:AreSame(obj2,list1:GetElement(3)).
    Assert:AreSame(obj3,list1:GetElement(4)).
    Assert:AreSame(obj4,list1:GetElement(5)).
  END METHOD.

  @Test.
  METHOD PUBLIC VOID InsertElementAfterEnd():
    list1:InsertElement(obj2, 10).
    Assert:AreSame(obj1,list1:GetElement(1)).
    Assert:AreSame(obj2,list1:GetElement(2)).
    Assert:AreSame(obj3,list1:GetElement(3)).
    Assert:AreSame(obj4,list1:GetElement(4)).
    Assert:AreSame(obj2,list1:GetElement(5)).
  END METHOD.

  @Test.
  METHOD PUBLIC VOID RemoveElement():
    list1:AddElement(list1:RemoveElement(1)).
    Assert:AreSame(obj2,list1:GetElement(1)).
    Assert:AreSame(obj1,list1:GetElement(4)).
    Assert:AreEqual(list1:Size, 4).
    list1:RemoveElement(4).
    Assert:AreEqual(list1:Size, 3).
  END METHOD.

  @Test.
  METHOD PUBLIC VOID RemoveAndDeleteElement():
    list1:RemoveAndDeleteElement(1).
    Assert:AreSame(obj2,list1:GetElement(1)).
    Assert:AreEqual(list1:Size, 3).
  END METHOD. 

  @Test.
  METHOD PUBLIC VOID SortElements():
    DEFINE VARIABLE comp AS IComparator NO-UNDO.
    comp = NEW SimpleComparator().
    list1:SortElements(comp).
    Assert:AreSame(obj1,list1:GetElement(4)).
    Assert:AreSame(obj2,list1:GetElement(3)).
    Assert:AreSame(obj3,list1:GetElement(2)).
    Assert:AreSame(obj4,list1:GetElement(1)).
    list1:SortElements(comp).
    Assert:AreSame(obj1,list1:GetElement(1)).
    Assert:AreSame(obj2,list1:GetElement(2)).
    Assert:AreSame(obj3,list1:GetElement(3)).
    Assert:AreSame(obj4,list1:GetElement(4)).
    FINALLY:
      DELETE OBJECT comp NO-ERROR.
    END FINALLY.
  END METHOD.
  
  
END CLASS.

